==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_functions/gridresult/FIELD.java <==

package net.datastream.schemas.mp_functions.gridresult;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="type" type="{http://schemas.datastream.net/MP_functions/GridResult}FIELD_TYPE" />
 *       &lt;attribute name="control" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="events" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="filterable" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="keyfield" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="label" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="lookup" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="order" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="visible" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="width" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="aliasnum" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="sortable" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "FIELD")
public class FIELD {

    @XmlAttribute(name = "type")
    protected FIELD_TYPE type;
    @XmlAttribute(name = "control")
    protected String control;
    @XmlAttribute(name = "events")
    protected String events;
    @XmlAttribute(name = "filterable")
    protected String filterable;
    @XmlAttribute(name = "keyfield")
    protected String keyfield;
    @XmlAttribute(name = "label")
    protected String label;
    @XmlAttribute(name = "lookup")
    protected String lookup;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "order")
    protected String order;
    @XmlAttribute(name = "visible")
    protected String visible;
    @XmlAttribute(name = "width")
    protected String width;
    @XmlAttribute(name = "aliasnum")
    protected BigInteger aliasnum;
    @XmlAttribute(name = "sortable")
    protected String sortable;

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link FIELD_TYPE }
     *     
     */
    public FIELD_TYPE getType() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link FIELD_TYPE }
     *     
     */
    public void setType(FIELD_TYPE value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété control.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getControl() {
        return control;
    }

    /**
     * Définit la valeur de la propriété control.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setControl(String value) {
        this.control = value;
    }

    /**
     * Obtient la valeur de la propriété events.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEvents() {
        return events;
    }

    /**
     * Définit la valeur de la propriété events.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEvents(String value) {
        this.events = value;
    }

    /**
     * Obtient la valeur de la propriété filterable.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFilterable() {
        return filterable;
    }

    /**
     * Définit la valeur de la propriété filterable.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFilterable(String value) {
        this.filterable = value;
    }

    /**
     * Obtient la valeur de la propriété keyfield.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKeyfield() {
        return keyfield;
    }

    /**
     * Définit la valeur de la propriété keyfield.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKeyfield(String value) {
        this.keyfield = value;
    }

    /**
     * Obtient la valeur de la propriété label.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLabel() {
        return label;
    }

    /**
     * Définit la valeur de la propriété label.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLabel(String value) {
        this.label = value;
    }

    /**
     * Obtient la valeur de la propriété lookup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLookup() {
        return lookup;
    }

    /**
     * Définit la valeur de la propriété lookup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLookup(String value) {
        this.lookup = value;
    }

    /**
     * Obtient la valeur de la propriété name.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Définit la valeur de la propriété name.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Obtient la valeur de la propriété order.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOrder() {
        return order;
    }

    /**
     * Définit la valeur de la propriété order.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOrder(String value) {
        this.order = value;
    }

    /**
     * Obtient la valeur de la propriété visible.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVisible() {
        return visible;
    }

    /**
     * Définit la valeur de la propriété visible.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVisible(String value) {
        this.visible = value;
    }

    /**
     * Obtient la valeur de la propriété width.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWidth() {
        return width;
    }

    /**
     * Définit la valeur de la propriété width.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWidth(String value) {
        this.width = value;
    }

    /**
     * Obtient la valeur de la propriété aliasnum.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getAliasnum() {
        return aliasnum;
    }

    /**
     * Définit la valeur de la propriété aliasnum.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setAliasnum(BigInteger value) {
        this.aliasnum = value;
    }

    /**
     * Obtient la valeur de la propriété sortable.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSortable() {
        return sortable;
    }

    /**
     * Définit la valeur de la propriété sortable.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSortable(String value) {
        this.sortable = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/gridresult/FIELD.java <==

package net.datastream.schemas.mp_functions.gridresult;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="type" type="{http://schemas.datastream.net/MP_functions/GridResult}FIELD_TYPE" />
 *       &lt;attribute name="control" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="events" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="filterable" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="keyfield" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="label" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="lookup" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="order" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="visible" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="width" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="aliasnum" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="sortable" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "FIELD")
public class FIELD {

    @XmlAttribute(name = "type")
    protected FIELD_TYPE type;
    @XmlAttribute(name = "control")
    protected String control;
    @XmlAttribute(name = "events")
    protected String events;
    @XmlAttribute(name = "filterable")
    protected String filterable;
    @XmlAttribute(name = "keyfield")
    protected String keyfield;
    @XmlAttribute(name = "label")
    protected String label;
    @XmlAttribute(name = "lookup")
    protected String lookup;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "order")
    protected String order;
    @XmlAttribute(name = "visible")
    protected String visible;
    @XmlAttribute(name = "width")
    protected String width;
    @XmlAttribute(name = "aliasnum")
    protected BigInteger aliasnum;
    @XmlAttribute(name = "sortable")
    protected String sortable;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link FIELD_TYPE }
     *     
     */
    public FIELD_TYPE getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link FIELD_TYPE }
     *     
     */
    public void setType(FIELD_TYPE value) {
        this.type = value;
    }

    /**
     * Gets the value of the control property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getControl() {
        return control;
    }

    /**
     * Sets the value of the control property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setControl(String value) {
        this.control = value;
    }

    /**
     * Gets the value of the events property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEvents() {
        return events;
    }

    /**
     * Sets the value of the events property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEvents(String value) {
        this.events = value;
    }

    /**
     * Gets the value of the filterable property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFilterable() {
        return filterable;
    }

    /**
     * Sets the value of the filterable property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFilterable(String value) {
        this.filterable = value;
    }

    /**
     * Gets the value of the keyfield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKeyfield() {
        return keyfield;
    }

    /**
     * Sets the value of the keyfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKeyfield(String value) {
        this.keyfield = value;
    }

    /**
     * Gets the value of the label property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLabel() {
        return label;
    }

    /**
     * Sets the value of the label property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLabel(String value) {
        this.label = value;
    }

    /**
     * Gets the value of the lookup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLookup() {
        return lookup;
    }

    /**
     * Sets the value of the lookup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLookup(String value) {
        this.lookup = value;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the order property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOrder() {
        return order;
    }

    /**
     * Sets the value of the order property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOrder(String value) {
        this.order = value;
    }

    /**
     * Gets the value of the visible property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVisible() {
        return visible;
    }

    /**
     * Sets the value of the visible property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVisible(String value) {
        this.visible = value;
    }

    /**
     * Gets the value of the width property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWidth() {
        return width;
    }

    /**
     * Sets the value of the width property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWidth(String value) {
        this.width = value;
    }

    /**
     * Gets the value of the aliasnum property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getAliasnum() {
        return aliasnum;
    }

    /**
     * Sets the value of the aliasnum property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setAliasnum(BigInteger value) {
        this.aliasnum = value;
    }

    /**
     * Gets the value of the sortable property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSortable() {
        return sortable;
    }

    /**
     * Sets the value of the sortable property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSortable(String value) {
        this.sortable = value;
    }

}
